"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chokidar_1 = require("chokidar");
const path_1 = require("path");
require("colors");
const app_host_config_1 = require("./app-host-config");
const logger_1 = require("./logger");
class Watcher {
    constructor(options) {
        this.options = options;
        logger_1.Logger.info(`Watcher options ${JSON.stringify(this.options)}`, 'watcher');
        this.config = new app_host_config_1.AppHostConfig();
        this.siteApplication = this.config.getSiteApplication(this.options.site);
    }
    run() {
        const path = path_1.resolve(this.siteApplication.physicalPath, this.options.paths);
        if (!path) {
            const error = `There is something weird with ${this.options.site} config.`;
            logger_1.Logger.error(error, 'watcher');
            throw new ReferenceError(error);
        }
        const watchOptions = {
            usePolling: true,
            interval: Number(this.options.interval),
            depth: this.options.depth > -1 ? Number(this.options.depth) : undefined
        };
        chokidar_1.watch(path, watchOptions).on('add', this.$add.bind(this));
        chokidar_1.watch(path, watchOptions).on('unlink', this.$remove.bind(this));
        logger_1.Logger.info(`Started watching on ${this.siteApplication.physicalPath}/${this.options.paths} (${this.options.site})`, 'watcher');
    }
    async $add(filePath) {
        const physicalPath = path_1.parse(filePath).dir;
        const path = this._toApplicationPath(physicalPath);
        await this.config.addSiteApplication(this.options.site, {
            path,
            pool: this.siteApplication.pool,
            physicalPath
        });
    }
    async $remove(filePath) {
        const physicalPath = path_1.parse(filePath).dir;
        const path = this._toApplicationPath(physicalPath);
        await this.config.removeSiteApplication(this.options.site, path);
    }
    _toApplicationPath(physicalPath) {
        const path = path_1.relative(this.siteApplication.physicalPath, physicalPath)
            .replace(/\\/g, '/');
        return path[0] === '/' ? path : `/${path}`;
    }
}
exports.Watcher = Watcher;
//# sourceMappingURL=watcher.js.map